.. _notebook_ex:

Cutout Helper Tools
===================

Cutout helper tools are useful for datasets from a large survey of
multiple sources, where there is a need to generate smaller cutout
images of interest.

Below is a `Jupyter notebook <https://jupyter.org/>`_ illustrating how
to create cutout images of sources from a larger image.  You can also
download the notebook for your own use from the `astroimtools GitHub
repository
<https://github.com/spacetelescope/astroimtools/tree/main/docs/notebooks>`_:

.. toctree::
    :maxdepth: 1

    notebooks/make_cutouts
